-file("/usr/lib/erlang/lib/parsetools-2.2/include/leexinc.hrl", 0).
%% The source of this file is part of leex distribution, as such it
%% has the same Copyright as the other files in the leex
%% distribution. The Copyright is defined in the accompanying file
%% COPYRIGHT. However, the resultant scanner generated by leex is the
%% property of the creator of the scanner and is not covered by that
%% Copyright.

-module(luerl_scan).

-export([string/1,string/2,token/2,token/3,tokens/2,tokens/3]).
-export([format_error/1]).

%% User code. This is placed here to allow extra attributes.
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 131).

-export([is_keyword/1]).

%% name_token(Chars, Line) ->
%%     {token,{'NAME',Line,Symbol}} | {Name,Line} | {error,E}.
%% Build a name from list of legal characters, else error.

name_token(Cs, L) ->
    case catch {ok,list_to_binary(Cs)} of
	{ok,Name} ->
	    case is_keyword(Name) of
		true -> {token,{name_string(Name),L}};
		false -> {token,{'NAME',L,Name}}
	    end;
	_ -> {error,"illegal name"}
    end.

name_string(Name) ->
    binary_to_atom(Name, latin1).		%Only latin1 in Lua

%% hex_float_token(TokenChars, TokenLine) ->
%%     {token,{'NUMERAL',TokenLine,Float}} | {error,E}.
%% Build a float form a hex float string.

hex_float_token(TokenChars, TokenLine) ->
    Tcs = string:substr(TokenChars, 3),
    case lists:splitwith(fun (C) -> (C =/= $p) and (C =/= $P) end, Tcs) of
	{Mcs,[]} when Mcs /= [] ->
	    hex_float(Mcs, [], TokenLine);
	{Mcs,[_P|Ecs]} when Ecs /= [] ->
	    hex_float(Mcs, Ecs, TokenLine);
	_Other -> {error,"malformed number"}
    end.

%% hex_float(Mantissa, Exponent) -> {token,{'NUMERAL',Line,Float}} | {error,E}.
%% hex_mantissa(Chars) -> {float,Float} | error.
%% hex_fraction(Chars, Pow, SoFar) -> Fraction.

hex_float(Mcs, [], Line) ->
    case hex_mantissa(Mcs) of
	{float,M} -> {token,{'NUMERAL',Line,M}};
	error -> {error,"malformed number"}
    end;
hex_float(Mcs, Ecs, Line) ->
    case hex_mantissa(Mcs) of
	{float,M} ->
	    case catch list_to_integer(Ecs, 10) of
		{'EXIT',_} -> {error,"malformed number"};
		E -> {token,{'NUMERAL',Line,M * math:pow(2, E)}}
	    end;
	error -> {error,"malformed number"}
    end.

hex_mantissa(Mcs) ->
    case lists:splitwith(fun (C) -> C =/= $. end, Mcs) of
	{[],[]} -> error;			%Nothing at all
	{[],[$.]} -> error;			%Only a '.'
	{[],[$.|Fcs]} -> {float,hex_fraction(Fcs, 16.0, 0.0)};
	{Hcs,[]} -> {float,float(list_to_integer(Hcs, 16))};
	{Hcs,[$.|Fcs]} ->
	    H = float(list_to_integer(Hcs, 16)),
	    {float,hex_fraction(Fcs, 16.0, H)}
    end.

hex_fraction([C|Cs], Pow, SoFar) when C >= $0, C =< $9 ->
    hex_fraction(Cs, Pow*16, SoFar + (C - $0)/Pow);
hex_fraction([C|Cs], Pow, SoFar) when C >= $a, C =< $f ->
    hex_fraction(Cs, Pow*16, SoFar + (C - $a + 10)/Pow);
hex_fraction([C|Cs], Pow, SoFar) when C >= $A, C =< $F ->
    hex_fraction(Cs, Pow*16, SoFar + (C - $A + 10)/Pow);
hex_fraction([], _Pow, SoFar) -> SoFar.

%% string_token(InputChars, Length, Line) ->
%%      {token,{'LITERALSTRING',Line,Cs}} | {error,E}.
%% Convert an input string into the corresponding string
%% characters. We know that the input string is correct.

string_token(Cs0, Len, L) ->
    Cs1 = string:substr(Cs0, 2, Len - 2),	%Strip quotes
    case catch {ok,chars(Cs1)} of
	{ok,Cs2} ->
	    %% Strings are utf8 encoded.
	    %% io:format("before: ~w\n", [Cs2]),
	    Str = case is_valid_utf8(Cs2) of
		      true ->
			  list_to_binary(Cs2);
		      false ->
			  unicode:characters_to_binary(Cs2, unicode, unicode)
		  end,
	    %% io:format("after: ~w\n", [Str]),
	    {token,{'LITERALSTRING',L,Str}};
	error -> {error,"illegal string"}
    end.

%% Valid UTF-8 bytes and where they can occur.
%% ascii          0 - 7F    0 - 127
%% continutaion  80 - BF  128 - 191
%% first with 1  C2 - DF  194 - 223
%% first with 2  E0 - EF  224 - 239
%% first with 3  F0 - F4  240 - 244

is_valid_utf8([C|Cs]) when C >= 0, C =< 127 -> is_valid_utf8(Cs);
is_valid_utf8([F1|Cs]) when F1 >= 194, F1 =< 223 -> is_cont_utf8(1, Cs);
is_valid_utf8([F2|Cs]) when F2 >= 224, F2 =< 239 -> is_cont_utf8(2, Cs);
is_valid_utf8([F3|Cs]) when F3 >= 240, F3 =< 244 -> is_cont_utf8(3, Cs);
is_valid_utf8([]) -> true;
is_valid_utf8(_Cs) -> false.

is_cont_utf8(1, [C|Cs]) when C >= 128, C =< 191 -> is_valid_utf8(Cs);
is_cont_utf8(N, [C|Cs]) when C >= 128, C =< 191 -> is_cont_utf8(N-1, Cs);
is_cont_utf8(_N, _Cs) -> false.

chars([$\\,C1|Cs0]) when C1 >= $0, C1 =< $9 ->	%1-3 decimal digits
    I1 = C1 - $0,
    case Cs0 of
	[C2|Cs1] when C2 >= $0, C2 =< $9 ->
	    I2 = C2 - $0,
	    case Cs1 of
		[C3|Cs2] when C3 >= $0, C3 =< $9 ->
		    [100*I1 + 10*I2 + (C3-$0)|chars(Cs2)];
		_ -> [10*I1 + I2|chars(Cs1)]
	    end;
	_ -> [I1|chars(Cs0)]
    end;
chars([$\\,$x,C1,C2|Cs]) ->			%2 hex digits
    case hex_char(C1) and hex_char(C2) of
	true -> [hex_val(C1)*16+hex_val(C2)|chars(Cs)];
	false -> throw(error)
    end;
chars([$\\,$z|Cs]) -> chars(skip_space(Cs));	%Skip blanks
chars([$\\,C|Cs]) -> [escape_char(C)|chars(Cs)];
chars([$\n|_]) -> throw(error);
chars([C|Cs]) -> [C|chars(Cs)];
chars([]) -> [].

skip_space([C|Cs]) when C >= 0, C =< $\s -> skip_space(Cs);
skip_space(Cs) -> Cs.

hex_char(C) when C >= $0, C =< $9 -> true;
hex_char(C) when C >= $a, C =< $f -> true;
hex_char(C) when C >= $A, C =< $F -> true;
hex_char(_) -> false.

hex_val(C) when C >= $0, C =< $9 -> C - $0;
hex_val(C) when C >= $a, C =< $f -> C - $a + 10;
hex_val(C) when C >= $A, C =< $F -> C - $A + 10.

escape_char($n) -> $\n;				%\n = LF
escape_char($r) -> $\r;				%\r = CR
escape_char($t) -> $\t;				%\t = TAB
escape_char($v) -> $\v;				%\v = VT
escape_char($b) -> $\b;				%\b = BS
escape_char($f) -> $\f;				%\f = FF
escape_char($e) -> $\e;				%\e = ESC
escape_char($s) -> $\s;				%\s = SPC
escape_char($d) -> $\d;				%\d = DEL
escape_char(C) -> C.

long_bracket(Line, [$\n|Cs]) ->
    S = list_to_binary(Cs),
    {token,{'LITERALSTRING',Line,S}};
long_bracket(Line, Cs) ->
    S = list_to_binary(Cs),
    {token,{'LITERALSTRING',Line,S}}.

%% is_keyword(Name) -> boolean().
%% Test if the name is a keyword.

is_keyword(<<"and">>) -> true;
is_keyword(<<"break">>) -> true;
is_keyword(<<"do">>) -> true;
is_keyword(<<"else">>) -> true;
is_keyword(<<"elseif">>) -> true;
is_keyword(<<"end">>) -> true;
is_keyword(<<"false">>) -> true;
is_keyword(<<"for">>) -> true;
is_keyword(<<"function">>) -> true;
is_keyword(<<"goto">>) -> true;
is_keyword(<<"if">>) -> true;
is_keyword(<<"in">>) -> true;
is_keyword(<<"local">>) -> true;
is_keyword(<<"nil">>) -> true;
is_keyword(<<"not">>) -> true;
is_keyword(<<"or">>) -> true;
is_keyword(<<"repeat">>) -> true;
is_keyword(<<"return">>) -> true;
is_keyword(<<"then">>) -> true;
is_keyword(<<"true">>) -> true;
is_keyword(<<"until">>) -> true;
is_keyword(<<"while">>) -> true;
is_keyword(_) -> false.

-file("/usr/lib/erlang/lib/parsetools-2.2/include/leexinc.hrl", 14).

format_error({illegal,S}) -> ["illegal characters ",io_lib:write_string(S)];
format_error({user,S}) -> S.

string(String) -> string(String, 1).

string(String, Line) -> string(String, Line, String, []).

%% string(InChars, Line, TokenChars, Tokens) ->
%% {ok,Tokens,Line} | {error,ErrorInfo,Line}.
%% Note the line number going into yystate, L0, is line of token
%% start while line number returned is line of token end. We want line
%% of token start.

string([], L, [], Ts) ->                     % No partial tokens!
    {ok,yyrev(Ts),L};
string(Ics0, L0, Tcs, Ts) ->
    case yystate(yystate(), Ics0, L0, 0, reject, 0) of
        {A,Alen,Ics1,L1} ->                  % Accepting end state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {A,Alen,Ics1,L1,_S1} ->              % Accepting transistion state
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        {reject,_Alen,Tlen,_Ics1,L1,_S1} ->  % After a non-accepting state
            {error,{L0,?MODULE,{illegal,yypre(Tcs, Tlen+1)}},L1};
        {A,Alen,Tlen,_Ics1,L1,_S1} ->
            Tcs1 = yysuf(Tcs, Alen),
            L2 = adjust_line(Tlen, Alen, Tcs1, L1),
            string_cont(Tcs1, L2, yyaction(A, Alen, Tcs, L0), Ts)
    end.

%% string_cont(RestChars, Line, Token, Tokens)
%% Test for and remove the end token wrapper. Push back characters
%% are prepended to RestChars.

-dialyzer({nowarn_function, string_cont/4}).

string_cont(Rest, Line, {token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, {end_token,T}, Ts) ->
    string(Rest, Line, Rest, [T|Ts]);
string_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T|Ts]);
string_cont(Rest, Line, skip_token, Ts) ->
    string(Rest, Line, Rest, Ts);
string_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, Ts);
string_cont(_Rest, Line, {error,S}, _Ts) ->
    {error,{Line,?MODULE,{user,S}},Line}.

%% token(Continuation, Chars) ->
%% token(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {token,State,CurrLine,TokenChars,TokenLen,TokenLine,AccAction,AccLen}

token(Cont, Chars) -> token(Cont, Chars, 1).

token([], Chars, Line) ->
    token(yystate(), Chars, Line, Chars, 0, Line, reject, 0);
token({token,State,Line,Tcs,Tlen,Tline,Action,Alen}, Chars, _) ->
    token(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Action, Alen).

%% token(State, InChars, Line, TokenChars, TokenLen, TokenLine,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% The argument order is chosen to be more efficient.

token(S0, Ics0, L0, Tcs, Tlen0, Tline, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{token,S1,L1,Tcs,Alen1,Tline,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{token,S1,L1,Tcs,Tlen1,Tline,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     true -> {eof,L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,Ics1,L1,_S1} ->    % No token match
            Error = {Tline,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            {done,{error,Error,L1},Ics1};
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->       % Use last accept match
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            token_cont(Tcs1, L2, yyaction(A1, Alen1, Tcs, Tline))
    end.

%% token_cont(RestChars, Line, Token)
%% If we have a token or error then return done, else if we have a
%% skip_token then continue.

-dialyzer({nowarn_function, token_cont/3}).

token_cont(Rest, Line, {token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, {end_token,T}) ->
    {done,{ok,T,Line},Rest};
token_cont(Rest, Line, {end_token,T,Push}) ->
    NewRest = Push ++ Rest,
    {done,{ok,T,Line},NewRest};
token_cont(Rest, Line, skip_token) ->
    token(yystate(), Rest, Line, Rest, 0, Line, reject, 0);
token_cont(Rest, Line, {skip_token,Push}) ->
    NewRest = Push ++ Rest,
    token(yystate(), NewRest, Line, NewRest, 0, Line, reject, 0);
token_cont(Rest, Line, {error,S}) ->
    {done,{error,{Line,?MODULE,{user,S}},Line},Rest}.

%% tokens(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Tokens,AccAction,AccLen}
%% {skip_tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Error,AccAction,AccLen}

tokens(Cont, Chars) -> tokens(Cont, Chars, 1).

tokens([], Chars, Line) ->
    tokens(yystate(), Chars, Line, Chars, 0, Line, [], reject, 0);
tokens({tokens,State,Line,Tcs,Tlen,Tline,Ts,Action,Alen}, Chars, _) ->
    tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Ts, Action, Alen);
tokens({skip_tokens,State,Line,Tcs,Tlen,Tline,Error,Action,Alen}, Chars, _) ->
    skip_tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Error, Action, Alen).

%% tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Ts, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1,Alen1,Ics1,L1} ->
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% Accepting transition state, can take more chars.
        {A1,Alen1,[],L1,S1} ->                  % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Alen1,Tline,Ts,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->               % Take what we got
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% After a non-accepting state, maybe reach accept state later.
        {A1,Alen1,Tlen1,[],L1,S1} ->            % Need more chars to check
            {more,{tokens,S1,L1,Tcs,Tlen1,Tline,Ts,A1,Alen1}};
        {reject,_Alen1,Tlen1,eof,L1,_S1} ->     % No token match
            %% Check for partial token which is error, no need to skip here.
            Ret = if Tlen1 > 0 -> {error,{Tline,?MODULE,
                                          %% Skip eof tail in Tcs.
                                          {illegal,yypre(Tcs, Tlen1)}},L1};
                     Ts == [] -> {eof,L1};
                     true -> {ok,yyrev(Ts),L1}
                  end,
            {done,Ret,eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            %% Skip rest of tokens.
            Error = {L1,?MODULE,{illegal,yypre(Tcs, Tlen1+1)}},
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            tokens_cont(Tcs1, L2, Token, Ts)
    end.

%% tokens_cont(RestChars, Line, Token, Tokens)
%% If we have an end_token or error then return done, else if we have
%% a token then save it and continue, else if we have a skip_token
%% just continue.

-dialyzer({nowarn_function, tokens_cont/4}).

tokens_cont(Rest, Line, {token,T}, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, [T|Ts], reject, 0);
tokens_cont(Rest, Line, {end_token,T}, Ts) ->
    {done,{ok,yyrev(Ts, [T]),Line},Rest};
tokens_cont(Rest, Line, {end_token,T,Push}, Ts) ->
    NewRest = Push ++ Rest,
    {done,{ok,yyrev(Ts, [T]),Line},NewRest};
tokens_cont(Rest, Line, skip_token, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {skip_token,Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {error,S}, _Ts) ->
    skip_tokens(Rest, Line, {Line,?MODULE,{user,S}}).

%%skip_tokens(InChars, Line, Error) -> {done,{error,Error,Line},Ics}.
%% Skip tokens until an end token, junk everything and return the error.

skip_tokens(Ics, Line, Error) ->
    skip_tokens(yystate(), Ics, Line, Ics, 0, Line, Error, reject, 0).

%% skip_tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

skip_tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Error, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        {A1,Alen1,Ics1,L1} ->                  % Accepting end state
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,[],L1,S1} ->                 % After an accepting state
            {more,{skip_tokens,S1,L1,Tcs,Alen1,Tline,Error,A1,Alen1}};
        {A1,Alen1,Ics1,L1,_S1} ->
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        {A1,Alen1,Tlen1,[],L1,S1} ->           % After a non-accepting state
            {more,{skip_tokens,S1,L1,Tcs,Tlen1,Tline,Error,A1,Alen1}};
        {reject,_Alen1,_Tlen1,eof,L1,_S1} ->
            {done,{error,Error,L1},eof};
        {reject,_Alen1,Tlen1,_Ics1,L1,_S1} ->
            skip_tokens(yysuf(Tcs, Tlen1+1), L1, Error);
        {A1,Alen1,Tlen1,_Ics1,L1,_S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            skip_cont(Tcs1, L2, Token, Error)
    end.

%% skip_cont(RestChars, Line, Token, Error)
%% Skip tokens until we have an end_token or error then return done
%% with the original rror.

-dialyzer({nowarn_function, skip_cont/4}).

skip_cont(Rest, Line, {token,_T}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {end_token,_T}, Error) ->
    {done,{error,Error,Line},Rest};
skip_cont(Rest, Line, {end_token,_T,Push}, Error) ->
    NewRest = Push ++ Rest,
    {done,{error,Error,Line},NewRest};
skip_cont(Rest, Line, skip_token, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {skip_token,Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {error,_S}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0).

-compile({nowarn_unused_function, [yyrev/1, yyrev/2, yypre/2, yysuf/2]}).

yyrev(List) -> lists:reverse(List).
yyrev(List, Tail) -> lists:reverse(List, Tail).
yypre(List, N) -> lists:sublist(List, N).
yysuf(List, N) -> lists:nthtail(N, List).

%% adjust_line(TokenLength, AcceptLength, Chars, Line) -> NewLine
%% Make sure that newlines in Chars are not counted twice.
%% Line has been updated with respect to newlines in the prefix of
%% Chars consisting of (TokenLength - AcceptLength) characters.

-compile({nowarn_unused_function, adjust_line/4}).

adjust_line(N, N, _Cs, L) -> L;
adjust_line(T, A, [$\n|Cs], L) ->
    adjust_line(T-1, A, Cs, L-1);
adjust_line(T, A, [_|Cs], L) ->
    adjust_line(T-1, A, Cs, L).

%% yystate() -> InitialState.
%% yystate(State, InChars, Line, CurrTokLen, AcceptAction, AcceptLen) ->
%% {Action, AcceptLen, RestChars, Line} |
%% {Action, AcceptLen, RestChars, Line, State} |
%% {reject, AcceptLen, CurrTokLen, RestChars, Line, State} |
%% {Action, AcceptLen, CurrTokLen, RestChars, Line, State}.
%% Generated state transition functions. The non-accepting end state
%% return signal either an unrecognised character or end of current
%% input.

-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.erl", 498).
yystate() -> 73.

yystate(76, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(68, Ics, Line, Tlen+1, Action, Alen);
yystate(76, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(68, Ics, Line, Tlen+1, Action, Alen);
yystate(76, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(72, Ics, Line, Tlen+1, Action, Alen);
yystate(76, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,76};
yystate(75, [160|Ics], Line, Tlen, _, _) ->
    yystate(75, Ics, Line, Tlen+1, 44, Tlen);
yystate(75, [32|Ics], Line, Tlen, _, _) ->
    yystate(75, Ics, Line, Tlen+1, 44, Tlen);
yystate(75, [9|Ics], Line, Tlen, _, _) ->
    yystate(75, Ics, Line, Tlen+1, 44, Tlen);
yystate(75, [10|Ics], Line, Tlen, _, _) ->
    yystate(75, Ics, Line+1, Tlen+1, 44, Tlen);
yystate(75, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 13 ->
    yystate(75, Ics, Line, Tlen+1, 44, Tlen);
yystate(75, Ics, Line, Tlen, _, _) ->
    {44,Tlen,Ics,Line,75};
yystate(74, [112|Ics], Line, Tlen, _, _) ->
    yystate(76, Ics, Line, Tlen+1, 7, Tlen);
yystate(74, [80|Ics], Line, Tlen, _, _) ->
    yystate(76, Ics, Line, Tlen+1, 7, Tlen);
yystate(74, [46|Ics], Line, Tlen, _, _) ->
    yystate(60, Ics, Line, Tlen+1, 7, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(64, Ics, Line, Tlen+1, 7, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 70 ->
    yystate(64, Ics, Line, Tlen+1, 7, Tlen);
yystate(74, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 102 ->
    yystate(64, Ics, Line, Tlen+1, 7, Tlen);
yystate(74, Ics, Line, Tlen, _, _) ->
    {7,Tlen,Ics,Line,74};
yystate(73, [160|Ics], Line, Tlen, Action, Alen) ->
    yystate(75, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [126|Ics], Line, Tlen, Action, Alen) ->
    yystate(69, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [125|Ics], Line, Tlen, Action, Alen) ->
    yystate(61, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [124|Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [123|Ics], Line, Tlen, Action, Alen) ->
    yystate(53, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [95|Ics], Line, Tlen, Action, Alen) ->
    yystate(49, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [94|Ics], Line, Tlen, Action, Alen) ->
    yystate(45, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [93|Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [91|Ics], Line, Tlen, Action, Alen) ->
    yystate(37, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [62|Ics], Line, Tlen, Action, Alen) ->
    yystate(21, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [61|Ics], Line, Tlen, Action, Alen) ->
    yystate(9, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [60|Ics], Line, Tlen, Action, Alen) ->
    yystate(1, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [59|Ics], Line, Tlen, Action, Alen) ->
    yystate(10, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [58|Ics], Line, Tlen, Action, Alen) ->
    yystate(14, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [48|Ics], Line, Tlen, Action, Alen) ->
    yystate(70, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [47|Ics], Line, Tlen, Action, Alen) ->
    yystate(56, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [46|Ics], Line, Tlen, Action, Alen) ->
    yystate(48, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(20, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [44|Ics], Line, Tlen, Action, Alen) ->
    yystate(19, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(23, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [42|Ics], Line, Tlen, Action, Alen) ->
    yystate(27, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [41|Ics], Line, Tlen, Action, Alen) ->
    yystate(31, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [40|Ics], Line, Tlen, Action, Alen) ->
    yystate(35, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(47, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [38|Ics], Line, Tlen, Action, Alen) ->
    yystate(51, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [37|Ics], Line, Tlen, Action, Alen) ->
    yystate(55, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [35|Ics], Line, Tlen, Action, Alen) ->
    yystate(59, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(71, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [32|Ics], Line, Tlen, Action, Alen) ->
    yystate(75, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [9|Ics], Line, Tlen, Action, Alen) ->
    yystate(75, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(75, Ics, Line+1, Tlen+1, Action, Alen);
yystate(73, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 13 ->
    yystate(75, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [C|Ics], Line, Tlen, Action, Alen) when C >= 49, C =< 57 ->
    yystate(22, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [C|Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 90 ->
    yystate(49, Ics, Line, Tlen+1, Action, Alen);
yystate(73, [C|Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 122 ->
    yystate(49, Ics, Line, Tlen+1, Action, Alen);
yystate(73, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,73};
yystate(72, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(72, Ics, Line, Tlen+1, 7, Tlen);
yystate(72, Ics, Line, Tlen, _, _) ->
    {7,Tlen,Ics,Line,72};
yystate(71, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(63, Ics, Line, Tlen+1, Action, Alen);
yystate(71, [34|Ics], Line, Tlen, Action, Alen) ->
    yystate(67, Ics, Line, Tlen+1, Action, Alen);
yystate(71, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(71, Ics, Line+1, Tlen+1, Action, Alen);
yystate(71, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(71, Ics, Line, Tlen+1, Action, Alen);
yystate(71, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 33 ->
    yystate(71, Ics, Line, Tlen+1, Action, Alen);
yystate(71, [C|Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(71, Ics, Line, Tlen+1, Action, Alen);
yystate(71, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(71, Ics, Line, Tlen+1, Action, Alen);
yystate(71, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,71};
yystate(70, [120|Ics], Line, Tlen, _, _) ->
    yystate(74, Ics, Line, Tlen+1, 1, Tlen);
yystate(70, [101|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line, Tlen+1, 1, Tlen);
yystate(70, [88|Ics], Line, Tlen, _, _) ->
    yystate(74, Ics, Line, Tlen+1, 1, Tlen);
yystate(70, [69|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line, Tlen+1, 1, Tlen);
yystate(70, [46|Ics], Line, Tlen, _, _) ->
    yystate(38, Ics, Line, Tlen+1, 1, Tlen);
yystate(70, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(22, Ics, Line, Tlen+1, 1, Tlen);
yystate(70, Ics, Line, Tlen, _, _) ->
    {1,Tlen,Ics,Line,70};
yystate(69, [61|Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen+1, 20, Tlen);
yystate(69, Ics, Line, Tlen, _, _) ->
    {20,Tlen,Ics,Line,69};
yystate(68, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(72, Ics, Line, Tlen+1, Action, Alen);
yystate(68, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,68};
yystate(67, Ics, Line, Tlen, _, _) ->
    {8,Tlen,Ics,Line};
yystate(66, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(66, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,66};
yystate(65, Ics, Line, Tlen, _, _) ->
    {25,Tlen,Ics,Line};
yystate(64, [112|Ics], Line, Tlen, _, _) ->
    yystate(76, Ics, Line, Tlen+1, 2, Tlen);
yystate(64, [80|Ics], Line, Tlen, _, _) ->
    yystate(76, Ics, Line, Tlen+1, 2, Tlen);
yystate(64, [46|Ics], Line, Tlen, _, _) ->
    yystate(60, Ics, Line, Tlen+1, 2, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(64, Ics, Line, Tlen+1, 2, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 70 ->
    yystate(64, Ics, Line, Tlen+1, 2, Tlen);
yystate(64, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 102 ->
    yystate(64, Ics, Line, Tlen+1, 2, Tlen);
yystate(64, Ics, Line, Tlen, _, _) ->
    {2,Tlen,Ics,Line,64};
yystate(63, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(71, Ics, Line+1, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(71, Ics, Line, Tlen+1, Action, Alen);
yystate(63, [C|Ics], Line, Tlen, Action, Alen) when C >= 11 ->
    yystate(71, Ics, Line, Tlen+1, Action, Alen);
yystate(63, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,63};
yystate(62, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(62, Ics, Line, Tlen+1, 3, Tlen);
yystate(62, Ics, Line, Tlen, _, _) ->
    {3,Tlen,Ics,Line,62};
yystate(61, Ics, Line, Tlen, _, _) ->
    {34,Tlen,Ics,Line};
yystate(60, [112|Ics], Line, Tlen, _, _) ->
    yystate(76, Ics, Line, Tlen+1, 7, Tlen);
yystate(60, [80|Ics], Line, Tlen, _, _) ->
    yystate(76, Ics, Line, Tlen+1, 7, Tlen);
yystate(60, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(60, Ics, Line, Tlen+1, 7, Tlen);
yystate(60, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 70 ->
    yystate(60, Ics, Line, Tlen+1, 7, Tlen);
yystate(60, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 102 ->
    yystate(60, Ics, Line, Tlen+1, 7, Tlen);
yystate(60, Ics, Line, Tlen, _, _) ->
    {7,Tlen,Ics,Line,60};
yystate(59, Ics, Line, Tlen, _, _) ->
    {23,Tlen,Ics,Line};
yystate(58, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(58, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(66, Ics, Line, Tlen+1, Action, Alen);
yystate(58, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(62, Ics, Line, Tlen+1, Action, Alen);
yystate(58, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,58};
yystate(57, Ics, Line, Tlen, _, _) ->
    {19,Tlen,Ics,Line};
yystate(56, [47|Ics], Line, Tlen, _, _) ->
    yystate(52, Ics, Line, Tlen+1, 14, Tlen);
yystate(56, Ics, Line, Tlen, _, _) ->
    {14,Tlen,Ics,Line,56};
yystate(55, Ics, Line, Tlen, _, _) ->
    {16,Tlen,Ics,Line};
yystate(54, [101|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 3, Tlen);
yystate(54, [69|Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen+1, 3, Tlen);
yystate(54, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(54, Ics, Line, Tlen+1, 3, Tlen);
yystate(54, Ics, Line, Tlen, _, _) ->
    {3,Tlen,Ics,Line,54};
yystate(53, Ics, Line, Tlen, _, _) ->
    {33,Tlen,Ics,Line};
yystate(52, Ics, Line, Tlen, _, _) ->
    {15,Tlen,Ics,Line};
yystate(51, Ics, Line, Tlen, _, _) ->
    {18,Tlen,Ics,Line};
yystate(50, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(46, Ics, Line, Tlen+1, Action, Alen);
yystate(50, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,50};
yystate(49, [95|Ics], Line, Tlen, _, _) ->
    yystate(49, Ics, Line, Tlen+1, 0, Tlen);
yystate(49, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(49, Ics, Line, Tlen+1, 0, Tlen);
yystate(49, [C|Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(49, Ics, Line, Tlen+1, 0, Tlen);
yystate(49, [C|Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(49, Ics, Line, Tlen+1, 0, Tlen);
yystate(49, Ics, Line, Tlen, _, _) ->
    {0,Tlen,Ics,Line,49};
yystate(48, [46|Ics], Line, Tlen, _, _) ->
    yystate(28, Ics, Line, Tlen+1, 41, Tlen);
yystate(48, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(44, Ics, Line, Tlen+1, 41, Tlen);
yystate(48, Ics, Line, Tlen, _, _) ->
    {41,Tlen,Ics,Line,48};
yystate(47, [92|Ics], Line, Tlen, Action, Alen) ->
    yystate(39, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [39|Ics], Line, Tlen, Action, Alen) ->
    yystate(43, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(47, Ics, Line+1, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(47, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 38 ->
    yystate(47, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 91 ->
    yystate(47, Ics, Line, Tlen+1, Action, Alen);
yystate(47, [C|Ics], Line, Tlen, Action, Alen) when C >= 93 ->
    yystate(47, Ics, Line, Tlen+1, Action, Alen);
yystate(47, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,47};
yystate(46, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(46, Ics, Line, Tlen+1, 5, Tlen);
yystate(46, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,46};
yystate(45, Ics, Line, Tlen, _, _) ->
    {17,Tlen,Ics,Line};
yystate(44, [101|Ics], Line, Tlen, _, _) ->
    yystate(40, Ics, Line, Tlen+1, 6, Tlen);
yystate(44, [69|Ics], Line, Tlen, _, _) ->
    yystate(40, Ics, Line, Tlen+1, 6, Tlen);
yystate(44, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(44, Ics, Line, Tlen+1, 6, Tlen);
yystate(44, Ics, Line, Tlen, _, _) ->
    {6,Tlen,Ics,Line,44};
yystate(43, Ics, Line, Tlen, _, _) ->
    {9,Tlen,Ics,Line};
yystate(42, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(50, Ics, Line, Tlen+1, Action, Alen);
yystate(42, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(46, Ics, Line, Tlen+1, Action, Alen);
yystate(42, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,42};
yystate(41, Ics, Line, Tlen, _, _) ->
    {36,Tlen,Ics,Line};
yystate(40, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen+1, Action, Alen);
yystate(40, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(40, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,40};
yystate(39, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(47, Ics, Line+1, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(47, Ics, Line, Tlen+1, Action, Alen);
yystate(39, [C|Ics], Line, Tlen, Action, Alen) when C >= 11 ->
    yystate(47, Ics, Line, Tlen+1, Action, Alen);
yystate(39, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,39};
yystate(38, [101|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 5, Tlen);
yystate(38, [69|Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen+1, 5, Tlen);
yystate(38, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(54, Ics, Line, Tlen+1, 5, Tlen);
yystate(38, Ics, Line, Tlen, _, _) ->
    {5,Tlen,Ics,Line,38};
yystate(37, [91|Ics], Line, Tlen, _, _) ->
    yystate(33, Ics, Line, Tlen+1, 35, Tlen);
yystate(37, Ics, Line, Tlen, _, _) ->
    {35,Tlen,Ics,Line,37};
yystate(36, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(36, Ics, Line, Tlen+1, 6, Tlen);
yystate(36, Ics, Line, Tlen, _, _) ->
    {6,Tlen,Ics,Line,36};
yystate(35, Ics, Line, Tlen, _, _) ->
    {31,Tlen,Ics,Line};
yystate(34, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(34, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,34};
yystate(33, [93|Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen+1, Action, Alen);
yystate(33, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(33, Ics, Line+1, Tlen+1, Action, Alen);
yystate(33, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(33, Ics, Line, Tlen+1, Action, Alen);
yystate(33, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 92 ->
    yystate(33, Ics, Line, Tlen+1, Action, Alen);
yystate(33, [C|Ics], Line, Tlen, Action, Alen) when C >= 94 ->
    yystate(33, Ics, Line, Tlen+1, Action, Alen);
yystate(33, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,33};
yystate(32, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(36, Ics, Line, Tlen+1, Action, Alen);
yystate(32, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,32};
yystate(31, Ics, Line, Tlen, _, _) ->
    {32,Tlen,Ics,Line};
yystate(30, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(30, Ics, Line, Tlen+1, 4, Tlen);
yystate(30, Ics, Line, Tlen, _, _) ->
    {4,Tlen,Ics,Line,30};
yystate(29, [93|Ics], Line, Tlen, Action, Alen) ->
    yystate(25, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(33, Ics, Line+1, Tlen+1, Action, Alen);
yystate(29, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(33, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 92 ->
    yystate(33, Ics, Line, Tlen+1, Action, Alen);
yystate(29, [C|Ics], Line, Tlen, Action, Alen) when C >= 94 ->
    yystate(33, Ics, Line, Tlen+1, Action, Alen);
yystate(29, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,29};
yystate(28, [46|Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen+1, 42, Tlen);
yystate(28, Ics, Line, Tlen, _, _) ->
    {42,Tlen,Ics,Line,28};
yystate(27, Ics, Line, Tlen, _, _) ->
    {13,Tlen,Ics,Line};
yystate(26, [45|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(26, [43|Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen+1, Action, Alen);
yystate(26, [C|Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(30, Ics, Line, Tlen+1, Action, Alen);
yystate(26, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,26};
yystate(25, Ics, Line, Tlen, _, _) ->
    {10,Tlen,Ics,Line};
yystate(24, Ics, Line, Tlen, _, _) ->
    {43,Tlen,Ics,Line};
yystate(23, Ics, Line, Tlen, _, _) ->
    {11,Tlen,Ics,Line};
yystate(22, [101|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line, Tlen+1, 1, Tlen);
yystate(22, [69|Ics], Line, Tlen, _, _) ->
    yystate(26, Ics, Line, Tlen+1, 1, Tlen);
yystate(22, [46|Ics], Line, Tlen, _, _) ->
    yystate(38, Ics, Line, Tlen+1, 1, Tlen);
yystate(22, [C|Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(22, Ics, Line, Tlen+1, 1, Tlen);
yystate(22, Ics, Line, Tlen, _, _) ->
    {1,Tlen,Ics,Line,22};
yystate(21, [62|Ics], Line, Tlen, _, _) ->
    yystate(17, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, [61|Ics], Line, Tlen, _, _) ->
    yystate(13, Ics, Line, Tlen+1, 29, Tlen);
yystate(21, Ics, Line, Tlen, _, _) ->
    {29,Tlen,Ics,Line,21};
yystate(20, [45|Ics], Line, Tlen, _, _) ->
    yystate(16, Ics, Line, Tlen+1, 12, Tlen);
yystate(20, Ics, Line, Tlen, _, _) ->
    {12,Tlen,Ics,Line,20};
yystate(19, Ics, Line, Tlen, _, _) ->
    {40,Tlen,Ics,Line};
yystate(18, Ics, Line, Tlen, _, _) ->
    {37,Tlen,Ics,Line};
yystate(17, Ics, Line, Tlen, _, _) ->
    {21,Tlen,Ics,Line};
yystate(16, [91|Ics], Line, Tlen, Action, Alen) ->
    yystate(12, Ics, Line, Tlen+1, Action, Alen);
yystate(16, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(11, Ics, Line+1, Tlen+1, Action, Alen);
yystate(16, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(15, Ics, Line, Tlen+1, Action, Alen);
yystate(16, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 90 ->
    yystate(15, Ics, Line, Tlen+1, Action, Alen);
yystate(16, [C|Ics], Line, Tlen, Action, Alen) when C >= 92 ->
    yystate(15, Ics, Line, Tlen+1, Action, Alen);
yystate(16, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,16};
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(15, Ics, Line, Tlen+1, 46, Tlen);
yystate(15, [C|Ics], Line, Tlen, _, _) when C >= 11 ->
    yystate(15, Ics, Line, Tlen+1, 46, Tlen);
yystate(15, Ics, Line, Tlen, _, _) ->
    {46,Tlen,Ics,Line,15};
yystate(14, [58|Ics], Line, Tlen, _, _) ->
    yystate(18, Ics, Line, Tlen+1, 39, Tlen);
yystate(14, Ics, Line, Tlen, _, _) ->
    {39,Tlen,Ics,Line,14};
yystate(13, Ics, Line, Tlen, _, _) ->
    {27,Tlen,Ics,Line};
yystate(12, [91|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(12, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(3, Ics, Line+1, Tlen+1, Action, Alen);
yystate(12, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(7, Ics, Line, Tlen+1, Action, Alen);
yystate(12, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 90 ->
    yystate(7, Ics, Line, Tlen+1, Action, Alen);
yystate(12, [C|Ics], Line, Tlen, Action, Alen) when C >= 92 ->
    yystate(7, Ics, Line, Tlen+1, Action, Alen);
yystate(12, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,12};
yystate(11, Ics, Line, Tlen, _, _) ->
    {45,Tlen,Ics,Line};
yystate(10, Ics, Line, Tlen, _, _) ->
    {38,Tlen,Ics,Line};
yystate(9, [61|Ics], Line, Tlen, _, _) ->
    yystate(5, Ics, Line, Tlen+1, 30, Tlen);
yystate(9, Ics, Line, Tlen, _, _) ->
    {30,Tlen,Ics,Line,9};
yystate(8, [93|Ics], Line, Tlen, Action, Alen) ->
    yystate(4, Ics, Line, Tlen+1, Action, Alen);
yystate(8, [10|Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line+1, Tlen+1, Action, Alen);
yystate(8, [C|Ics], Line, Tlen, Action, Alen) when C >= 0, C =< 9 ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(8, [C|Ics], Line, Tlen, Action, Alen) when C >= 11, C =< 92 ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(8, [C|Ics], Line, Tlen, Action, Alen) when C >= 94 ->
    yystate(0, Ics, Line, Tlen+1, Action, Alen);
yystate(8, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,8};
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(7, Ics, Line, Tlen+1, 48, Tlen);
yystate(7, [C|Ics], Line, Tlen, _, _) when C >= 11 ->
    yystate(7, Ics, Line, Tlen+1, 48, Tlen);
yystate(7, Ics, Line, Tlen, _, _) ->
    {48,Tlen,Ics,Line,7};
yystate(6, Ics, Line, Tlen, _, _) ->
    {22,Tlen,Ics,Line};
yystate(5, Ics, Line, Tlen, _, _) ->
    {24,Tlen,Ics,Line};
yystate(4, Ics, Line, Tlen, _, _) ->
    {49,Tlen,Ics,Line};
yystate(3, Ics, Line, Tlen, _, _) ->
    {47,Tlen,Ics,Line};
yystate(2, Ics, Line, Tlen, _, _) ->
    {26,Tlen,Ics,Line};
yystate(1, [61|Ics], Line, Tlen, _, _) ->
    yystate(2, Ics, Line, Tlen+1, 28, Tlen);
yystate(1, [60|Ics], Line, Tlen, _, _) ->
    yystate(6, Ics, Line, Tlen+1, 28, Tlen);
yystate(1, Ics, Line, Tlen, _, _) ->
    {28,Tlen,Ics,Line,1};
yystate(0, [93|Ics], Line, Tlen, _, _) ->
    yystate(8, Ics, Line, Tlen+1, 50, Tlen);
yystate(0, [10|Ics], Line, Tlen, _, _) ->
    yystate(0, Ics, Line+1, Tlen+1, 50, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(0, Ics, Line, Tlen+1, 50, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 11, C =< 92 ->
    yystate(0, Ics, Line, Tlen+1, 50, Tlen);
yystate(0, [C|Ics], Line, Tlen, _, _) when C >= 94 ->
    yystate(0, Ics, Line, Tlen+1, 50, Tlen);
yystate(0, Ics, Line, Tlen, _, _) ->
    {50,Tlen,Ics,Line,0};
yystate(S, Ics, Line, Tlen, Action, Alen) ->
    {Action,Alen,Tlen,Ics,Line,S}.

%% yyaction(Action, TokenLength, TokenChars, TokenLine) ->
%% {token,Token} | {end_token, Token} | skip_token | {error,String}.
%% Generated action function.

yyaction(0, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_0(TokenChars, TokenLine);
yyaction(1, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_1(TokenChars, TokenLine);
yyaction(2, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_2(TokenChars, TokenLine);
yyaction(3, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_3(TokenChars, TokenLine);
yyaction(4, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_4(TokenChars, TokenLine);
yyaction(5, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_5(TokenChars, TokenLine);
yyaction(6, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_6(TokenChars, TokenLine);
yyaction(7, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_7(TokenChars, TokenLine);
yyaction(8, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_8(TokenChars, TokenLen, TokenLine);
yyaction(9, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_9(TokenChars, TokenLen, TokenLine);
yyaction(10, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_10(TokenChars, TokenLen, TokenLine);
yyaction(11, _, _, TokenLine) ->
    yyaction_11(TokenLine);
yyaction(12, _, _, TokenLine) ->
    yyaction_12(TokenLine);
yyaction(13, _, _, TokenLine) ->
    yyaction_13(TokenLine);
yyaction(14, _, _, TokenLine) ->
    yyaction_14(TokenLine);
yyaction(15, _, _, TokenLine) ->
    yyaction_15(TokenLine);
yyaction(16, _, _, TokenLine) ->
    yyaction_16(TokenLine);
yyaction(17, _, _, TokenLine) ->
    yyaction_17(TokenLine);
yyaction(18, _, _, TokenLine) ->
    yyaction_18(TokenLine);
yyaction(19, _, _, TokenLine) ->
    yyaction_19(TokenLine);
yyaction(20, _, _, TokenLine) ->
    yyaction_20(TokenLine);
yyaction(21, _, _, TokenLine) ->
    yyaction_21(TokenLine);
yyaction(22, _, _, TokenLine) ->
    yyaction_22(TokenLine);
yyaction(23, _, _, TokenLine) ->
    yyaction_23(TokenLine);
yyaction(24, _, _, TokenLine) ->
    yyaction_24(TokenLine);
yyaction(25, _, _, TokenLine) ->
    yyaction_25(TokenLine);
yyaction(26, _, _, TokenLine) ->
    yyaction_26(TokenLine);
yyaction(27, _, _, TokenLine) ->
    yyaction_27(TokenLine);
yyaction(28, _, _, TokenLine) ->
    yyaction_28(TokenLine);
yyaction(29, _, _, TokenLine) ->
    yyaction_29(TokenLine);
yyaction(30, _, _, TokenLine) ->
    yyaction_30(TokenLine);
yyaction(31, _, _, TokenLine) ->
    yyaction_31(TokenLine);
yyaction(32, _, _, TokenLine) ->
    yyaction_32(TokenLine);
yyaction(33, _, _, TokenLine) ->
    yyaction_33(TokenLine);
yyaction(34, _, _, TokenLine) ->
    yyaction_34(TokenLine);
yyaction(35, _, _, TokenLine) ->
    yyaction_35(TokenLine);
yyaction(36, _, _, TokenLine) ->
    yyaction_36(TokenLine);
yyaction(37, _, _, TokenLine) ->
    yyaction_37(TokenLine);
yyaction(38, _, _, TokenLine) ->
    yyaction_38(TokenLine);
yyaction(39, _, _, TokenLine) ->
    yyaction_39(TokenLine);
yyaction(40, _, _, TokenLine) ->
    yyaction_40(TokenLine);
yyaction(41, _, _, TokenLine) ->
    yyaction_41(TokenLine);
yyaction(42, _, _, TokenLine) ->
    yyaction_42(TokenLine);
yyaction(43, _, _, TokenLine) ->
    yyaction_43(TokenLine);
yyaction(44, _, _, _) ->
    yyaction_44();
yyaction(45, _, _, _) ->
    yyaction_45();
yyaction(46, _, _, _) ->
    yyaction_46();
yyaction(47, _, _, _) ->
    yyaction_47();
yyaction(48, _, _, _) ->
    yyaction_48();
yyaction(49, _, _, _) ->
    yyaction_49();
yyaction(50, _, _, _) ->
    yyaction_50();
yyaction(_, _, _, _) -> error.

-compile({inline,yyaction_0/2}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 28).
yyaction_0(TokenChars, TokenLine) ->
     name_token (TokenChars, TokenLine) .

-compile({inline,yyaction_1/2}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 32).
yyaction_1(TokenChars, TokenLine) ->
     case catch { ok, list_to_integer (TokenChars) } of
     { ok, I } -> { token, { 'NUMERAL', TokenLine, I } } ;
     _ -> { error, "illegal number" }
     end .

-compile({inline,yyaction_2/2}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 37).
yyaction_2(TokenChars, TokenLine) ->
     Int = list_to_integer (string : substr (TokenChars, 3), 16),
     { token, { 'NUMERAL', TokenLine, Int } } .

-compile({inline,yyaction_3/2}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 42).
yyaction_3(TokenChars, TokenLine) ->
     case catch { ok, list_to_float (TokenChars) } of
     { ok, F } -> { token, { 'NUMERAL', TokenLine, F } } ;
     _ -> { error, "illegal number" }
     end .

-compile({inline,yyaction_4/2}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 47).
yyaction_4(TokenChars, TokenLine) ->
     [M, E ] = string : tokens (TokenChars, "eE"),
     case catch { ok, list_to_float (M ++ ".0e" ++ E) } of
     { ok, F } -> { token, { 'NUMERAL', TokenLine, F } } ;
     _ -> { error, "illegal number" }
     end .

-compile({inline,yyaction_5/2}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 53).
yyaction_5(TokenChars, TokenLine) ->
     [M | E ] = string : tokens (TokenChars, "."),
     case catch { ok, list_to_float (lists : append ([M, ".0" | E ])) } of
     { ok, F } -> { token, { 'NUMERAL', TokenLine, F } } ;
     _ -> { error, "illegal number" }
     end .

-compile({inline,yyaction_6/2}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 59).
yyaction_6(TokenChars, TokenLine) ->
     case catch { ok, list_to_float ("0" ++ TokenChars) } of
     { ok, F } -> { token, { 'NUMERAL', TokenLine, F } } ;
     _ -> { error, "illegal number" }
     end .

-compile({inline,yyaction_7/2}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 68).
yyaction_7(TokenChars, TokenLine) ->
     hex_float_token (TokenChars, TokenLine) .

-compile({inline,yyaction_8/3}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 73).
yyaction_8(TokenChars, TokenLen, TokenLine) ->
     string_token (TokenChars, TokenLen, TokenLine) .

-compile({inline,yyaction_9/3}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 75).
yyaction_9(TokenChars, TokenLen, TokenLine) ->
     string_token (TokenChars, TokenLen, TokenLine) .

-compile({inline,yyaction_10/3}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 78).
yyaction_10(TokenChars, TokenLen, TokenLine) ->
     Cs = string : substr (TokenChars, 3, TokenLen - 4),
     long_bracket (TokenLine, Cs) .

-compile({inline,yyaction_11/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 82).
yyaction_11(TokenLine) ->
     { token, { '+', TokenLine } } .

-compile({inline,yyaction_12/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 83).
yyaction_12(TokenLine) ->
     { token, { '-', TokenLine } } .

-compile({inline,yyaction_13/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 84).
yyaction_13(TokenLine) ->
     { token, { '*', TokenLine } } .

-compile({inline,yyaction_14/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 85).
yyaction_14(TokenLine) ->
     { token, { '/', TokenLine } } .

-compile({inline,yyaction_15/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 86).
yyaction_15(TokenLine) ->
     { token, { '//', TokenLine } } .

-compile({inline,yyaction_16/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 87).
yyaction_16(TokenLine) ->
     { token, { '%', TokenLine } } .

-compile({inline,yyaction_17/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 88).
yyaction_17(TokenLine) ->
     { token, { '^', TokenLine } } .

-compile({inline,yyaction_18/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 89).
yyaction_18(TokenLine) ->
     { token, { '&', TokenLine } } .

-compile({inline,yyaction_19/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 90).
yyaction_19(TokenLine) ->
     { token, { '|', TokenLine } } .

-compile({inline,yyaction_20/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 91).
yyaction_20(TokenLine) ->
     { token, { '~', TokenLine } } .

-compile({inline,yyaction_21/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 92).
yyaction_21(TokenLine) ->
     { token, { '>>', TokenLine } } .

-compile({inline,yyaction_22/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 93).
yyaction_22(TokenLine) ->
     { token, { '<<', TokenLine } } .

-compile({inline,yyaction_23/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 94).
yyaction_23(TokenLine) ->
     { token, { '#', TokenLine } } .

-compile({inline,yyaction_24/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 95).
yyaction_24(TokenLine) ->
     { token, { '==', TokenLine } } .

-compile({inline,yyaction_25/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 96).
yyaction_25(TokenLine) ->
     { token, { '~=', TokenLine } } .

-compile({inline,yyaction_26/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 97).
yyaction_26(TokenLine) ->
     { token, { '<=', TokenLine } } .

-compile({inline,yyaction_27/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 98).
yyaction_27(TokenLine) ->
     { token, { '>=', TokenLine } } .

-compile({inline,yyaction_28/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 99).
yyaction_28(TokenLine) ->
     { token, { '<', TokenLine } } .

-compile({inline,yyaction_29/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 100).
yyaction_29(TokenLine) ->
     { token, { '>', TokenLine } } .

-compile({inline,yyaction_30/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 101).
yyaction_30(TokenLine) ->
     { token, { '=', TokenLine } } .

-compile({inline,yyaction_31/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 102).
yyaction_31(TokenLine) ->
     { token, { '(', TokenLine } } .

-compile({inline,yyaction_32/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 103).
yyaction_32(TokenLine) ->
     { token, { ')', TokenLine } } .

-compile({inline,yyaction_33/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 104).
yyaction_33(TokenLine) ->
     { token, { '{', TokenLine } } .

-compile({inline,yyaction_34/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 105).
yyaction_34(TokenLine) ->
     { token, { '}', TokenLine } } .

-compile({inline,yyaction_35/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 106).
yyaction_35(TokenLine) ->
     { token, { '[', TokenLine } } .

-compile({inline,yyaction_36/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 107).
yyaction_36(TokenLine) ->
     { token, { ']', TokenLine } } .

-compile({inline,yyaction_37/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 108).
yyaction_37(TokenLine) ->
     { token, { '::', TokenLine } } .

-compile({inline,yyaction_38/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 109).
yyaction_38(TokenLine) ->
     { token, { ';', TokenLine } } .

-compile({inline,yyaction_39/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 110).
yyaction_39(TokenLine) ->
     { token, { ':', TokenLine } } .

-compile({inline,yyaction_40/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 111).
yyaction_40(TokenLine) ->
     { token, { ',', TokenLine } } .

-compile({inline,yyaction_41/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 112).
yyaction_41(TokenLine) ->
     { token, { '.', TokenLine } } .

-compile({inline,yyaction_42/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 113).
yyaction_42(TokenLine) ->
     { token, { '..', TokenLine } } .

-compile({inline,yyaction_43/1}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 114).
yyaction_43(TokenLine) ->
     { token, { '...', TokenLine } } .

-compile({inline,yyaction_44/0}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 116).
yyaction_44() ->
     skip_token .

-compile({inline,yyaction_45/0}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 120).
yyaction_45() ->
     skip_token .

-compile({inline,yyaction_46/0}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 121).
yyaction_46() ->
     skip_token .

-compile({inline,yyaction_47/0}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 122).
yyaction_47() ->
     skip_token .

-compile({inline,yyaction_48/0}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 123).
yyaction_48() ->
     skip_token .

-compile({inline,yyaction_49/0}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 126).
yyaction_49() ->
     skip_token .

-compile({inline,yyaction_50/0}).
-file("/root/rpmbuild/BUILD/mongooseim-4.1.0/_build/default/lib/luerl/src/luerl_scan.xrl", 127).
yyaction_50() ->
     { error, "unfinished long comment" } .

-file("/usr/lib/erlang/lib/parsetools-2.2/include/leexinc.hrl", 313).
